@@ -1,9 +1,10 @@
 # -*- coding: utf8 -*-
+from ..typing import AttributeDescriptor
 from .. import descriptors
 from .handler import OnGetHandler, OnSetHandler, OnDelHandler, OnChangeHandler
 from .value import Value
 
-class Descriptor(descriptors.Named):
+class Descriptor(AttributeDescriptor, descriptors.Named):
     ValueType = Value
     on_get = OnGetHandler()
     on_set = OnSetHandler()
