@@ -8,11 +8,11 @@ class Handler(events.Handler, Named):
     default = events.Handler
     class ValueType(Value):
         def init_value(self, value):
-            super(type(self), self).init_value(None)
-            self.set(value())
+            super(type(self), self).init_value(value())
 
     def __hash__(self):
         return id(self)
 
 
+
 Subject = events.Subject(Handler)
