@@ -1,12 +1,14 @@
 # -*- coding: utf8 -*-
 from .exceptions import StopPropagation
+from ..typing import AbstractEvent
 
-class Event(object):
+class Event(AbstractEvent):
     def __init__(self, *args, **kwargs):
         self.args = args
         for name, value in list(kwargs.items()):
             setattr(self, name, value)
-
+        if getattr(self, '__channel__', None) is None:
+            setattr(self, '__channel__', type(self).__name__)
         self.messages = []
         self.results = []
 
@@ -19,6 +21,3 @@ class Event(object):
 
     def returns(self):
         return self
-
-
-
