@@ -1,24 +1,30 @@
 # -*- coding: utf8 -*-
 from .exceptions import StopPropagation
 from .event import Event
+from ..typing import AbstractHandler, Modifiers
 
 
-class EventType(object):
-    def __init__(self, event_type):
-        self.event_type = event_type
-    def visit(self, handler):
-        handler.event_type = self.event_type
+always_true = lambda event: True
 
-def always_true(event):
-    return True
+class HandlerModifiers(Modifiers):
 
-class Handler(list):
+    def refuse(self, visited, visitor):
+        """if not a visitor, it is a callback"""
+        visited.append(visitor)
+
+    def reject(self, visited, visitor):
+        self.remove(visitor)
+
+class Handler(AbstractHandler):
     event_type = Event
     def __init__(self, *callbacks, **options):
+        self.visitors = HandlerModifiers(callbacks)
         self.events = tuple()
         for item, value in tuple(options.items()):
             setattr(self, item, value)
-        self.visitors = tuple(map(self.apply, callbacks))
+
+        self.visitors.visit(self)
+
 
     @property
     def condition(self):
@@ -33,11 +39,6 @@ class Handler(list):
     def condition(self):
         delattr(self, '_condition')
 
-
-    def apply(self, callback):
-        visit = getattr(callback, 'visit', lambda *a: self.append(callback))
-        return visit(self)
-
     def notify(self, *args, **kwargs):
         event = self.make_event(*args, **kwargs)
         return self.propagate(event)
@@ -49,16 +50,22 @@ class Handler(list):
         return self.propagate(event).returns()
 
     def propagate(self, event):
-        self.events = self.events + (event, )
+        self.events += (event, )
         try:
-            getattr(self, 'before_propagation', always_true)(event)
+            self.before_propagation(event)
             self._assert_condition(event)
             tuple(map(event.trigger, self))
-            getattr(self, 'after_propagation', always_true)
+            self.after_propagation(event)
         except StopPropagation:
             pass
         return event
 
+    def before_propagation(self, event):
+        pass
+
+    def after_propagation(self, event):
+        pass
+
     def _assert_condition(self, event):
         if not self.condition(event):
             msg = "Condition '%s' for event '%s' return False"
@@ -93,6 +100,12 @@ class Handler(list):
         self._assert_list_valid(callbacks)
         return list.extend(self, callbacks)
 
+    def update(self, other):
+        self.extend(other)
+        self.condition = getattr(other, 'condition', self.condition)
+        self.visitors.extend(self, getattr(other, 'visitors', []))
+        return self
+
     def clear_events(self):
         self.events = tuple()
 
