@@ -9,10 +9,12 @@ class After(events.Handler):
     event_type = AfterEvent
 
 
-class BeforeDescriptor(descriptors.Handler):
+class BeforeHandler(descriptors.Handler):
+    __alias__ = 'before'
     default = Before
 
-class AfterDescriptor(descriptors.Handler):
+class AfterHandler(descriptors.Handler):
+    __alias__ = 'after'
     default = After
 
-Subject = events.Subject(Before, After)
+Subject = events.Subject(BeforeHandler, AfterHandler)
